@@ -246,6 +246,7 @@ namespace giac {
    when all fork/child etc. will be removed */
   extern vecteur plot_instructions;
 #endif
+  extern bool gnuplot_opengl;
   int gnuplot_show_pnt(const symbolic & e,GIAC_CONTEXT);
 
   gen rationalparam2equation(const gen & at_orig,const gen & t_orig,const gen &x,const gen & y,GIAC_CONTEXT);
@@ -829,6 +830,17 @@ namespace giac {
   extern const unary_function_ptr * const  implicittex_plot_sommets;
 #endif
 
+// colormap support, addition by L.Marohnić
+bool is_colormap_index(int pal);
+bool is_colormap_cyclic(int pal);
+int colormap_color(int pal,double t,GIAC_CONTEXT=context0);
+bool colormap_color_rgb(int pal,double t,int &c,int &r,int &g,int &b,GIAC_CONTEXT=context0);
+gen _colormap(const gen &g,GIAC_CONTEXT);
+extern const unary_function_ptr * const at_colormap;
+void rgb2xyz(double R,double G,double B,double &x,double &y,double &z);
+void xyz2rgb(double x,double y,double z,double &R,double &G,double &B);
+gen _bezier(const gen & args,GIAC_CONTEXT);
+
 #ifndef NO_NAMESPACE_GIAC
 } // namespace giac
 #endif // ndef NO_NAMESPACE_GIAC
